@@ -33,7 +33,7 @@ func Run() (err error) {
 	app := cli.NewApp()
 	app.Name = "croc"
 	if Version == "" {
-		Version = "v9.6.1-b27982a"
+		Version = "v9.6.2-3b81934"
 	}
 	app.Version = Version
 	app.Compiled = time.Now()
@@ -166,9 +166,9 @@ func determinePass(c *cli.Context) (pass string) {
 func send(c *cli.Context) (err error) {
 	setDebugLevel(c)
 	comm.Socks5Proxy = c.String("socks5")
-	portsString:=c.String("ports")
-	if portsString=="" {
-		portsString="9009,9010,9011,9012,9013"
+	portsString := c.String("ports")
+	if portsString == "" {
+		portsString = "9009,9010,9011,9012,9013"
 	}
 	crocOptions := croc.Options{
 		SharedSecret:   c.String("code"),
@@ -234,6 +234,9 @@ func send(c *cli.Context) (err error) {
 		if !c.IsSet("local") {
 			crocOptions.OnlyLocal = rememberedOptions.OnlyLocal
 		}
+		if !c.IsSet("hash") {
+			crocOptions.HashAlgorithm = rememberedOptions.HashAlgorithm
+		}
 	}
 
 	var fnames []string
@@ -340,7 +343,7 @@ func saveConfig(c *cli.Context, crocOptions croc.Options) {
 			log.Error(err)
 			return
 		}
-		err = os.WriteFile(configFile, bConfig, 0644)
+		err = os.WriteFile(configFile, bConfig, 0o644)
 		if err != nil {
 			log.Error(err)
 			return
@@ -448,7 +451,7 @@ func receive(c *cli.Context) (err error) {
 			log.Error(err)
 			return
 		}
-		err = os.WriteFile(configFile, bConfig, 0644)
+		err = os.WriteFile(configFile, bConfig, 0o644)
 		if err != nil {
 			log.Error(err)
 			return
